% Generated by roxygen2 (4.0.2): do not edit by hand
\name{linear.regression.performance.test}
\alias{linear.reg.compute.rw}
\alias{linear.reg.generate.data}
\alias{linear.reg.rw}
\alias{linear.regression.performance.test}
\title{A performance test that runs a set of linear regression algorithms.}
\usage{
linear.regression.performance.test(nfile = 256, run.vec = 1,
  MAP.TASKS = 44, RED.TASKS = 44, n = 10, p.vec = 2^4 - 1, m.vec = 8,
  g.vec = 0, BLK.vec = 27, REP.vec = 3, REUSE.vec = c(1, -1),
  hdfs.dir = rhoptions()$HADOOP.TMP.FOLDER, sleep = 60,
  delete.data = FALSE)

linear.reg.generate.data(REP.vec = 3, BLK.vec = 27, m.vec = 8,
  p.vec = 2^4 - 1, n = 10, n.file = 256, run = 1, MAP.TASKS = 44,
  hdfs.dir = rhoptions()$HADOOP.TMP.FOLDER, sleep = 60)

linear.reg.compute.rw(REP.vec = 3, BLK.vec = 27, REUSE.vec = c(1, -1),
  g.vec = 0, m.vec = 8, p.vec = 2^4 - 1, MAP.TASKS = 44,
  RED.TASKS = 44, run = 1, hdfs.dir = rhoptions()$HADOOP.TMP.FOLDER,
  sleep = 60)

linear.reg.rw(REP.vec = 3, BLK.vec = 27, REUSE.vec = c(1, -1),
  g.vec = 0, m.vec = 8, p.vec = 2^4 - 1, MAP.TASKS = 44,
  RED.TASKS = 44, run = 1, hdfs.dir = rhoptions()$HADOOP.TMP.FOLDER,
  sleep = 60)
}
\arguments{
\item{nfile}{Number of files for the input data}

\item{run.vec}{Vector of replicate run IDs}

\item{MAP.TASKS}{Number of map tasks}

\item{RED.TASKS}{Number of reduce tasks}

\item{n}{log2 number of observations}

\item{p.vec}{Number of predictor variables (numeric vector)}

\item{m.vec}{log2 number of observations per subset (numeric vector)}

\item{g.vec}{log2 number of subset groups (numeric vector)}

\item{BLK.vec}{log2 HDFS block size}

\item{REP.vec}{HDFS replication factor}

\item{REUSE.vec}{Task JVM reuse, does not re-generate data (numeric vector, 1, -1)}

\item{hdfs.dir}{HDFS directory for saving datasets and results}

\item{sleep}{Break time in seconds between jobs}

\item{delete.data}{TRUE/FALSE delete linear regression data before exiting function?}
}
\value{
timing data.frame of timing results
}
\description{
The function \bold{linear.regression.performance.test} constructs a set of linear
regression problems to solve using Rhipe, and reports timing statistics for
three steps:
\enumerate{
   \item Create datasets (linear.reg.generate.data)
   \item Fit linear regression, including read/write time (linear.reg.compute.rw)
   \item Read/write time only for step 2 (linear.reg.rw)
}

The function \bold{linear.reg.generate.data} generates datasets for the
linear regression performance tests.

The function \bold{linear.reg.comput.rw} collects times for calculation and
read/write time for the linear regression performance tests.

The function \bold{linear.reg.rw} collects times for read/write only for
the linear regression performance tests.
}
\details{
Notes on order in which the factors are varied when generating data
or computing the linear regressions, from slowest to fastest
\enumerate{
  \item run.vec: replicated runs
  \item REP.vec, BLK.vec: data are re-generated
  \item REUSE.vec, g.vec: factors does not need re-generating data
  \item m.vec, p.vec: they always run together as a unit
}
}
\examples{
library(Rhipe)
rhinit()
rhoptions(readback = FALSE)
timing.df <- linear.regression.performance.test(nfile=256, run.vec=1:2, RED.TASKS=1,
    n=10, p.vec=2^4:6 - 1, m.vec=8:16, g.vec=c(0, 7, 14), BLK.vec=c(),
    REP.vec=c(), REUSE.vec=c(1, -1), hdfs.dir=rhoptions()$HADOOP.TMP.FOLDER,
    sleep=60)
}

